/***********************************************************************************************************************************
Perl Configuration
***********************************************************************************************************************************/
#ifndef PERL_CONFIG_H
#define PERL_CONFIG_H

#include "common/type/string.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
String *perlOptionJson(void);

#endif
